@@ -6,7 +6,7 @@ use Devel::REPL::Plugin;
 use PPI;
 use PPI::Dumper;
 
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 
 sub BEFORE_PLUGIN {
     my $self = shift;
